summaryrefslogtreecommitdiffstats
path: root/kaudiocreator/job.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
commitb1057f437bf65300831a0ccb45b920787c6b318d (patch)
treef8a73db06ca1180d0da0ba6dfbe786197b4f4bc3 /kaudiocreator/job.cpp
parent4ddfca384ced9ad654213aef9dc2c3973720b980 (diff)
downloadtdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.tar.gz
tdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.zip
TQt4 port kdemultimedia
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1236079 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kaudiocreator/job.cpp')
-rw-r--r--kaudiocreator/job.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kaudiocreator/job.cpp b/kaudiocreator/job.cpp
index 740aeb5e..c4950377 100644
--- a/kaudiocreator/job.cpp
+++ b/kaudiocreator/job.cpp
@@ -21,7 +21,7 @@
#include <tqregexp.h>
/**
* A helper function to replace %X with the stuff in the album.
* if quote is true then put "" around the %X
*/
TQString Job::replaceSpecialChars(const TQString &string, bool quote, TQMap<TQString, TQString> _map){
@@ -45,14 +45,14 @@ TQString Job::replaceSpecialChars(const TQString &string, bool quote, TQMap<TQSt
}
void Job::fix(const TQString &in, const TQString &out){
- track_title.replace( TQRegExp(in), out );
- track_artist.replace( TQRegExp(in), out );
- track_comment.replace( TQRegExp(in), out );
+ track_title.tqreplace( TQRegExp(in), out );
+ track_artist.tqreplace( TQRegExp(in), out );
+ track_comment.tqreplace( TQRegExp(in), out );
// year
// track
- genre.replace( TQRegExp(in), out );
- album.replace( TQRegExp(in), out );
- comment.replace( TQRegExp(in), out );
- group.replace( TQRegExp(in), out );
+ genre.tqreplace( TQRegExp(in), out );
+ album.tqreplace( TQRegExp(in), out );
+ comment.tqreplace( TQRegExp(in), out );
+ group.tqreplace( TQRegExp(in), out );
}
@@ -21,7 +21,7 @@
#include <tqregexp.h>
/**
- * A helper function to replace %X with the stuff in the album.
+ * A helper function to tqreplace %X with the stuff in the album.
* if quote is true then put "" around the %X
*/